@@ -2,78 +2,46 @@ package Lingua::AR::Word;
 
 use strict;
 use utf8;
+use Switch;
 
 
 sub stem{
 
-  my $stem;
-  my $word=shift;
-
-
-  #let's strip down every prefix and suffix I'm aware of.
-  #(actually suffixes relative to people like possessive adjs are NOT chopped)
-
-	if($word=~/^(	#the prefixes
-		[وفب]*ال|
-		[بيلمتوسن]*ت|
-		[بلوكف]*م|
-		[ال]*ل|[
-		ولسف]*ي|[
-		وفلب]*ا|
-		)
-		(.*?)	# the stem
-		(	# the suffixes
-		ات|
-		وا|
-		تا|
-		ون|
-		وه|
-		ان|
-		تي|
-		ته|
-		تم|
-		كم|
-		ه[نم]*|
-		ها|
-		ية|
-		تك|
-		نا|
-		ي[نه]*|
-		[ةهيا]|
-		)
-		$/x)
+	my $stem;
+	my $word=$_[0];
+	
+	#let's strip down every prefix and suffix I'm aware of
+	if($word=~/^([وفب]*ال|[بيلمتوسن]*ت|[بلوكف]*م|[ال]*ل|[ولسف]*ي|[وفلب]*ا|)(.*?)(ات|وا|تا|ون|وه|ان|تي|ته|تم|كم|ه[نم]*|ها|ية|تك|نا|ي[نه]*|[ةهيا]|)$/)
 	{
  		$word=$2;
        }
 
-       #let's strip down all other unnecessary letters according to the length of the word
-       if(length($word)==3){
-           $stem=$word;
-       }
-       else{
-           if(length($word)==4){
-               $stem=&four($word);
-           }
-           else{
-               if(length($word)==5){
-                   $stem=&five($word);
-               }
-               else{
-                   if(length($word)==6){
-                       $stem=&six($word);
-                   }
-                   else{
-                       $stem="NotFound";
-                   }
-               }
-           }
-       }
+       #let's strip down all other unnecessary letters
+       my $length=length($word);
 
+       switch($length){
+			case 3	{
+				$stem=$word;
+			}
+			case 4	{
+				$stem=&four($word);
+			}
+			case 5	{
+				$stem=&five($word);
+			}
+			case 6	{
+				$stem=&six($word);
+			}
+			else	{
+				$stem="NotFound";
+			}
+
+       }
 return $stem;
 }
 
 sub four{
-	my $word=shift;
+	my $word=$_[0];
 	
 	if($word=~/(.)(.)(ا|ي|و)(.)/){
 		$word=$1.$2.$4;
@@ -87,7 +55,7 @@ sub four{
 }
 
 sub five{
-	my $word=shift;
+	my $word=$_[0];
 	
 	if($word=~/(.)(.)(ا)(ا)(.)/){
 		$word=$1.$2.$5;
@@ -115,7 +83,7 @@ sub five{
 }
 
 sub six{
-	my $word=shift;
+	my $word=$_[0];
 	
 	if($word=~/(.)(و)(ا)(.)(ي)(.)/){
 		$word=$1.$4.$6;
@@ -134,13 +102,13 @@ __END__
 
 =head1 NAME
 
-Lingua::AR::Word::Stem - Perl extension to find the stem of a given Arabic word
+Lingua::AR::Word::Stem - Perl extension for finding the stem of a given Arabic word
 
 =head1 SYNOPSIS
 
-	use Lingua::AR::Word::Stem;
+  use Lingua::AR::Word::Stem;
 
-	$stem=Lingua::AR::Word::stem("ARABIC_WORD_IN_UTF8");
+$stem=Lingua::AR::Word::stem(ARABIC_WORD_IN_UTF8);
 
 =head1 DESCRIPTION
 
@@ -153,7 +121,7 @@ Andrea Benazzo, E<lt>andy@slacky.itE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006 Andrea Benazzo. All rights reserved.
+Copyright (c) 2005 Andrea Benazzo. All rights reserved.
  This program is free software; you can redistribute it and/or
  modify it under the same terms as Perl itself.
 
